// SPDX-FileCopyrightText: (C) 2025  James Turner <james@flightgear.org>
// SPDX-License-Identifier: GPL-2.0-or-later


#include "test_controls.hxx"
#include "test_history.hxx"

CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(ControlsTests, "Unit tests");
CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(HistoryTests, "Unit tests");
